==> elasticache-1.93.0-sources.jar: software/amazon/awscdk/services/elasticache/CfnUserGroupProps.java <==
package software.amazon.awscdk.services.elasticache;

/**
 * Properties for defining a `AWS::ElastiCache::UserGroup`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:21.551Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticache.$Module.class, fqn = "@aws-cdk/aws-elasticache.CfnUserGroupProps")
@software.amazon.jsii.Jsii.Proxy(CfnUserGroupProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnUserGroupProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ElastiCache::UserGroup.Engine`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getEngine();

    /**
     * `AWS::ElastiCache::UserGroup.UserGroupId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUserGroupId();

    /**
     * `AWS::ElastiCache::UserGroup.UserIds`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getUserIds() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnUserGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnUserGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnUserGroupProps> {
        private java.lang.String engine;
        private java.lang.String userGroupId;
        private java.util.List<java.lang.String> userIds;

        /**
         * Sets the value of {@link CfnUserGroupProps#getEngine}
         * @param engine `AWS::ElastiCache::UserGroup.Engine`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder engine(java.lang.String engine) {
            this.engine = engine;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserGroupProps#getUserGroupId}
         * @param userGroupId `AWS::ElastiCache::UserGroup.UserGroupId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userGroupId(java.lang.String userGroupId) {
            this.userGroupId = userGroupId;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserGroupProps#getUserIds}
         * @param userIds `AWS::ElastiCache::UserGroup.UserIds`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userIds(java.util.List<java.lang.String> userIds) {
            this.userIds = userIds;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnUserGroupProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnUserGroupProps build() {
            return new Jsii$Proxy(engine, userGroupId, userIds);
        }
    }

    /**
     * An implementation for {@link CfnUserGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnUserGroupProps {
        private final java.lang.String engine;
        private final java.lang.String userGroupId;
        private final java.util.List<java.lang.String> userIds;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.engine = software.amazon.jsii.Kernel.get(this, "engine", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.userGroupId = software.amazon.jsii.Kernel.get(this, "userGroupId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.userIds = software.amazon.jsii.Kernel.get(this, "userIds", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String engine, final java.lang.String userGroupId, final java.util.List<java.lang.String> userIds) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.engine = java.util.Objects.requireNonNull(engine, "engine is required");
            this.userGroupId = java.util.Objects.requireNonNull(userGroupId, "userGroupId is required");
            this.userIds = userIds;
        }

        @Override
        public final java.lang.String getEngine() {
            return this.engine;
        }

        @Override
        public final java.lang.String getUserGroupId() {
            return this.userGroupId;
        }

        @Override
        public final java.util.List<java.lang.String> getUserIds() {
            return this.userIds;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("engine", om.valueToTree(this.getEngine()));
            data.set("userGroupId", om.valueToTree(this.getUserGroupId()));
            if (this.getUserIds() != null) {
                data.set("userIds", om.valueToTree(this.getUserIds()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-elasticache.CfnUserGroupProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnUserGroupProps.Jsii$Proxy that = (CfnUserGroupProps.Jsii$Proxy) o;

            if (!engine.equals(that.engine)) return false;
            if (!userGroupId.equals(that.userGroupId)) return false;
            return this.userIds != null ? this.userIds.equals(that.userIds) : that.userIds == null;
        }

        @Override
        public final int hashCode() {
            int result = this.engine.hashCode();
            result = 31 * result + (this.userGroupId.hashCode());
            result = 31 * result + (this.userIds != null ? this.userIds.hashCode() : 0);
            return result;
        }
    }
}

==> elasticache-1.204.0-sources.jar: software/amazon/awscdk/services/elasticache/CfnUserGroupProps.java <==
package software.amazon.awscdk.services.elasticache;

/**
 * Properties for defining a <code>CfnUserGroup</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.elasticache.*;
 * CfnUserGroupProps cfnUserGroupProps = CfnUserGroupProps.builder()
 *         .engine("engine")
 *         .userGroupId("userGroupId")
 *         .userIds(List.of("userIds"))
 *         // the properties below are optional
 *         .tags(List.of(CfnTag.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:29:56.512Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticache.$Module.class, fqn = "@aws-cdk/aws-elasticache.CfnUserGroupProps")
@software.amazon.jsii.Jsii.Proxy(CfnUserGroupProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnUserGroupProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The current supported value is redis.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getEngine();

    /**
     * The ID of the user group.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUserGroupId();

    /**
     * The list of user IDs that belong to the user group.
     * <p>
     * A user named <code>default</code> must be included.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getUserIds();

    /**
     * <code>AWS::ElastiCache::UserGroup.Tags</code>.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnUserGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnUserGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnUserGroupProps> {
        java.lang.String engine;
        java.lang.String userGroupId;
        java.util.List<java.lang.String> userIds;
        java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnUserGroupProps#getEngine}
         * @param engine The current supported value is redis. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder engine(java.lang.String engine) {
            this.engine = engine;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserGroupProps#getUserGroupId}
         * @param userGroupId The ID of the user group. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userGroupId(java.lang.String userGroupId) {
            this.userGroupId = userGroupId;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserGroupProps#getUserIds}
         * @param userIds The list of user IDs that belong to the user group. This parameter is required.
         *                A user named <code>default</code> must be included.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userIds(java.util.List<java.lang.String> userIds) {
            this.userIds = userIds;
            return this;
        }

        /**
         * Sets the value of {@link CfnUserGroupProps#getTags}
         * @param tags <code>AWS::ElastiCache::UserGroup.Tags</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnUserGroupProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnUserGroupProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnUserGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnUserGroupProps {
        private final java.lang.String engine;
        private final java.lang.String userGroupId;
        private final java.util.List<java.lang.String> userIds;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.engine = software.amazon.jsii.Kernel.get(this, "engine", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.userGroupId = software.amazon.jsii.Kernel.get(this, "userGroupId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.userIds = software.amazon.jsii.Kernel.get(this, "userIds", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.engine = java.util.Objects.requireNonNull(builder.engine, "engine is required");
            this.userGroupId = java.util.Objects.requireNonNull(builder.userGroupId, "userGroupId is required");
            this.userIds = java.util.Objects.requireNonNull(builder.userIds, "userIds is required");
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)builder.tags;
        }

        @Override
        public final java.lang.String getEngine() {
            return this.engine;
        }

        @Override
        public final java.lang.String getUserGroupId() {
            return this.userGroupId;
        }

        @Override
        public final java.util.List<java.lang.String> getUserIds() {
            return this.userIds;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("engine", om.valueToTree(this.getEngine()));
            data.set("userGroupId", om.valueToTree(this.getUserGroupId()));
            data.set("userIds", om.valueToTree(this.getUserIds()));
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-elasticache.CfnUserGroupProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnUserGroupProps.Jsii$Proxy that = (CfnUserGroupProps.Jsii$Proxy) o;

            if (!engine.equals(that.engine)) return false;
            if (!userGroupId.equals(that.userGroupId)) return false;
            if (!userIds.equals(that.userIds)) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.engine.hashCode();
            result = 31 * result + (this.userGroupId.hashCode());
            result = 31 * result + (this.userIds.hashCode());
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
